@@ -1,16 +1,11 @@
-#!/usr/bin/env python3
-import sys
-from .utils import INF, Plane, get_bound, uniq, csort, fsplit
+from .utils import INF, Plane, get_bound, uniq, fsplit
 from .utils import bbox2str, matrix2str, apply_matrix_pt
 
 
-##  IndexAssigner
-##
-class IndexAssigner(object):
+class IndexAssigner:
 
     def __init__(self, index=0):
         self.index = index
-        return
 
     def run(self, obj):
         if isinstance(obj, LTTextBox):
@@ -19,21 +14,12 @@ class IndexAssigner(object):
         elif isinstance(obj, LTTextGroup):
             for x in obj:
                 self.run(x)
-        return
 
 
-##  LAParams
-##
-class LAParams(object):
+class LAParams:
 
-    def __init__(self,
-                 line_overlap=0.5,
-                 char_margin=2.0,
-                 line_margin=0.5,
-                 word_margin=0.1,
-                 boxes_flow=0.5,
-                 detect_vertical=False,
-                 all_texts=False):
+    def __init__(self, line_overlap=0.5, char_margin=2.0, line_margin=0.5, word_margin=0.1,
+            boxes_flow=0.5, detect_vertical=False, all_texts=False):
         self.line_overlap = line_overlap
         self.char_margin = char_margin
         self.line_margin = line_margin
@@ -41,25 +27,19 @@ class LAParams(object):
         self.boxes_flow = boxes_flow
         self.detect_vertical = detect_vertical
         self.all_texts = all_texts
-        return
 
     def __repr__(self):
         return ('<LAParams: char_margin=%.1f, line_margin=%.1f, word_margin=%.1f all_texts=%r>' %
                 (self.char_margin, self.line_margin, self.word_margin, self.all_texts))
 
 
-##  LTItem
-##
-class LTItem(object):
+class LTItem:
 
     def analyze(self, laparams):
         """Perform the layout analysis."""
-        return
 
 
-##  LTText
-##
-class LTText(object):
+class LTText:
 
     def __repr__(self):
         return ('<%s %r>' %
@@ -69,18 +49,14 @@ class LTText(object):
         raise NotImplementedError
 
 
-##  LTComponent
-##
 class LTComponent(LTItem):
 
     def __init__(self, bbox):
         LTItem.__init__(self)
         self.set_bbox(bbox)
-        return
 
     def __repr__(self):
-        return ('<%s %s>' %
-                (self.__class__.__name__, bbox2str(self.bbox)))
+        return ('<%s %s>' % (self.__class__.__name__, bbox2str(self.bbox)))
 
     def set_bbox(self, bbox):
         (x0,y0,x1,y1) = bbox
@@ -91,7 +67,6 @@ class LTComponent(LTItem):
         self.width = x1-x0
         self.height = y1-y0
         self.bbox = (x0, y0, x1, y1)
-        return
 
     def is_empty(self):
         return self.width <= 0 or self.height <= 0
@@ -133,41 +108,30 @@ class LTComponent(LTItem):
             return 0
 
 
-##  LTCurve
-##
 class LTCurve(LTComponent):
 
     def __init__(self, linewidth, pts):
         LTComponent.__init__(self, get_bound(pts))
         self.pts = pts
         self.linewidth = linewidth
-        return
 
     def get_pts(self):
         return ','.join( '%.3f,%.3f' % p for p in self.pts )
 
 
-##  LTLine
-##
 class LTLine(LTCurve):
 
     def __init__(self, linewidth, p0, p1):
         LTCurve.__init__(self, linewidth, [p0, p1])
-        return
 
 
-##  LTRect
-##
 class LTRect(LTCurve):
 
     def __init__(self, linewidth, rect):
         (x0,y0,x1,y1) = rect
         LTCurve.__init__(self, linewidth, [(x0,y0), (x1,y0), (x1,y1), (x0,y1)])
-        return
 
 
-##  LTImage
-##
 class LTImage(LTComponent):
 
     def __init__(self, name, stream, bbox):
@@ -181,7 +145,6 @@ class LTImage(LTComponent):
         self.colorspace = stream.get_any(('CS', 'ColorSpace'))
         if not isinstance(self.colorspace, list):
             self.colorspace = [self.colorspace]
-        return
 
     def __repr__(self):
         return ('<%s(%s) %s %r>' %
@@ -189,20 +152,15 @@ class LTImage(LTComponent):
                  bbox2str(self.bbox), self.srcsize))
 
 
-##  LTAnon
-##
 class LTAnon(LTItem, LTText):
 
     def __init__(self, text):
         self._text = text
-        return
 
     def get_text(self):
         return self._text
 
 
-##  LTChar
-##
 class LTChar(LTComponent, LTText):
 
     def __init__(self, matrix, font, fontsize, scaling, rise, text, textwidth, textdisp):
@@ -245,7 +203,6 @@ class LTChar(LTComponent, LTText):
             self.size = self.width
         else:
             self.size = self.height
-        return
 
     def __repr__(self):
         return ('<%s %s matrix=%s font=%r adv=%s text=%r>' %
@@ -261,14 +218,11 @@ class LTChar(LTComponent, LTText):
         return True
 
     
-##  LTContainer
-##
 class LTContainer(LTComponent):
 
     def __init__(self, bbox):
         LTComponent.__init__(self, bbox)
         self._objs = []
-        return
 
     def __iter__(self):
         return iter(self._objs)
@@ -278,55 +232,42 @@ class LTContainer(LTComponent):
 
     def add(self, obj):
         self._objs.append(obj)
-        return
 
     def extend(self, objs):
         for obj in objs:
             self.add(obj)
-        return
 
     def analyze(self, laparams):
         for obj in self._objs:
             obj.analyze(laparams)
-        return
     
 
-##  LTExpandableContainer
-##
 class LTExpandableContainer(LTContainer):
 
     def __init__(self):
         LTContainer.__init__(self, (+INF,+INF,-INF,-INF))
-        return
 
     def add(self, obj):
         LTContainer.add(self, obj)
         self.set_bbox((min(self.x0, obj.x0), min(self.y0, obj.y0),
                        max(self.x1, obj.x1), max(self.y1, obj.y1)))
-        return
 
 
-##  LTTextContainer
-##
 class LTTextContainer(LTExpandableContainer, LTText):
 
     def __init__(self):
         LTText.__init__(self)
         LTExpandableContainer.__init__(self)
-        return
 
     def get_text(self):
         return ''.join( obj.get_text() for obj in self if isinstance(obj, LTText) )
     
 
-##  LTTextLine
-##
 class LTTextLine(LTTextContainer):
 
     def __init__(self, word_margin):
         LTTextContainer.__init__(self)
         self.word_margin = word_margin
-        return
 
     def __repr__(self):
         return ('<%s %s %r>' %
@@ -336,7 +277,6 @@ class LTTextLine(LTTextContainer):
     def analyze(self, laparams):
         LTTextContainer.analyze(self, laparams)
         LTContainer.add(self, LTAnon('\n'))
-        return
 
     def find_neighbors(self, plane, ratio):
         raise NotImplementedError
@@ -346,7 +286,6 @@ class LTTextLineHorizontal(LTTextLine):
     def __init__(self, word_margin):
         LTTextLine.__init__(self, word_margin)
         self._x1 = +INF
-        return
 
     def add(self, obj):
         if isinstance(obj, LTChar) and self.word_margin:
@@ -355,7 +294,6 @@ class LTTextLineHorizontal(LTTextLine):
                 LTContainer.add(self, LTAnon(' '))
         self._x1 = obj.x1
         LTTextLine.add(self, obj)
-        return
 
     def find_neighbors(self, plane, ratio):
         h = ratio*self.height
@@ -367,7 +305,6 @@ class LTTextLineVertical(LTTextLine):
     def __init__(self, word_margin):
         LTTextLine.__init__(self, word_margin)
         self._y0 = -INF
-        return
 
     def add(self, obj):
         if isinstance(obj, LTChar) and self.word_margin:
@@ -376,7 +313,6 @@ class LTTextLineVertical(LTTextLine):
                 LTContainer.add(self, LTAnon(' '))
         self._y0 = obj.y0
         LTTextLine.add(self, obj)
-        return
         
     def find_neighbors(self, plane, ratio):
         w = ratio*self.width
@@ -384,17 +320,14 @@ class LTTextLineVertical(LTTextLine):
         return [ obj for obj in objs if isinstance(obj, LTTextLineVertical) ]
     
 
-##  LTTextBox
-##
 ##  A set of text objects that are grouped within
 ##  a certain rectangular area.
-##
+
 class LTTextBox(LTTextContainer):
 
     def __init__(self):
         LTTextContainer.__init__(self)
         self.index = None
-        return
 
     def __repr__(self):
         return ('<%s(%s) %s %r>' %
@@ -405,8 +338,7 @@ class LTTextBoxHorizontal(LTTextBox):
     
     def analyze(self, laparams):
         LTTextBox.analyze(self, laparams)
-        self._objs = csort(self._objs, key=lambda obj: -obj.y1)
-        return
+        self._objs = sorted(self._objs, key=lambda obj: -obj.y1)
 
     def get_writing_mode(self):
         return 'lr-tb'
@@ -415,51 +347,42 @@ class LTTextBoxVertical(LTTextBox):
 
     def analyze(self, laparams):
         LTTextBox.analyze(self, laparams)
-        self._objs = csort(self._objs, key=lambda obj: -obj.x1)
-        return
+        self._objs = sorted(self._objs, key=lambda obj: -obj.x1)
 
     def get_writing_mode(self):
         return 'tb-rl'
 
 
-##  LTTextGroup
-##
 class LTTextGroup(LTTextContainer):
 
     def __init__(self, objs):
         LTTextContainer.__init__(self)
         self.extend(objs)
-        return
 
 class LTTextGroupLRTB(LTTextGroup):
     
     def analyze(self, laparams):
         LTTextGroup.analyze(self, laparams)
         # reorder the objects from top-left to bottom-right.
-        self._objs = csort(self._objs, key=lambda obj:
+        self._objs = sorted(self._objs, key=lambda obj:
                            (1-laparams.boxes_flow)*(obj.x0) -
                            (1+laparams.boxes_flow)*(obj.y0+obj.y1))
-        return
 
 class LTTextGroupTBRL(LTTextGroup):
     
     def analyze(self, laparams):
         LTTextGroup.analyze(self, laparams)
         # reorder the objects from top-right to bottom-left.
-        self._objs = csort(self._objs, key=lambda obj:
+        self._objs = sorted(self._objs, key=lambda obj:
                            -(1+laparams.boxes_flow)*(obj.x0+obj.x1)
                            -(1-laparams.boxes_flow)*(obj.y1))
-        return
 
 
-##  LTLayoutContainer
-##
 class LTLayoutContainer(LTContainer):
 
     def __init__(self, bbox):
         LTContainer.__init__(self, bbox)
         self.groups = None
-        return
         
     def get_textlines(self, laparams, objs):
         obj0 = None
@@ -525,7 +448,6 @@ class LTLayoutContainer(LTContainer):
             line = LTTextLineHorizontal(laparams.word_margin)
             line.add(obj0)
         yield line
-        return
 
     def get_textboxes(self, laparams, lines):
         plane = Plane(lines)
@@ -551,7 +473,6 @@ class LTLayoutContainer(LTContainer):
             if box in done: continue
             done.add(box)
             yield box
-        return
 
     def group_textboxes(self, laparams, boxes):
         def dist(obj1, obj2):
@@ -587,10 +508,9 @@ class LTLayoutContainer(LTContainer):
             for j in range(i+1, len(boxes)):
                 obj2 = boxes[j]
                 dists.append((0, dist(obj1, obj2), obj1, obj2))
-        try:
-            dists.sort()
-        except TypeError:
-            dists.sort(key=lambda o: id(o))
+        # we sort by dist and our tuple is (c,dist,obj1,obj2)
+        sortkey = lambda tup: tup[1]
+        dists.sort(key=sortkey)
         plane = Plane(boxes)
         while dists:
             (c,d,obj1,obj2) = dists.pop(0)
@@ -610,10 +530,7 @@ class LTLayoutContainer(LTContainer):
                       if o1 in plane and o2 in plane ]
             for other in plane:
                 dists.append((0, dist(group,other), group, other))
-            try:
-                dists.sort()
-            except TypeError:
-                dists.sort(key=lambda o: id(o))
+            dists.sort(key=sortkey)
             plane.add(group)
         assert len(plane) == 1
         return list(plane)
@@ -624,7 +541,8 @@ class LTLayoutContainer(LTContainer):
         (textobjs, otherobjs) = fsplit(lambda obj: isinstance(obj, LTChar), self._objs)
         for obj in otherobjs:
             obj.analyze(laparams)
-        if not textobjs: return
+        if not textobjs:
+            return
         textlines = list(self.get_textlines(laparams, textobjs))
         assert len(textobjs) <= sum( len(line._objs) for line in textlines )
         (empties, textlines) = fsplit(lambda obj: obj.is_empty(), textlines)
@@ -640,11 +558,8 @@ class LTLayoutContainer(LTContainer):
         textboxes.sort(key=lambda box:box.index)
         self._objs = textboxes + otherobjs + empties
         self.groups = groups
-        return
 
 
-##  LTFigure
-##
 class LTFigure(LTLayoutContainer):
 
     def __init__(self, name, bbox, matrix):
@@ -654,7 +569,6 @@ class LTFigure(LTLayoutContainer):
         bbox = get_bound( apply_matrix_pt(matrix, (p,q))
                           for (p,q) in ((x,y), (x+w,y), (x,y+h), (x+w,y+h)) )
         LTLayoutContainer.__init__(self, bbox)
-        return
 
     def __repr__(self):
         return ('<%s(%s) %s matrix=%s>' %
@@ -662,20 +576,17 @@ class LTFigure(LTLayoutContainer):
                  bbox2str(self.bbox), matrix2str(self.matrix)))
 
     def analyze(self, laparams):
-        if not laparams.all_texts: return
+        if not laparams.all_texts:
+            return
         LTLayoutContainer.analyze(self, laparams)
-        return 
 
 
-##  LTPage
-##
 class LTPage(LTLayoutContainer):
 
     def __init__(self, pageid, bbox, rotate=0):
         LTLayoutContainer.__init__(self, bbox)
         self.pageid = pageid
         self.rotate = rotate
-        return
 
     def __repr__(self):
         return ('<%s(%r) %s rotate=%r>' %
